PCB Environment: dsn::Padstack Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Padstack Struct Reference

## Public Member Functions
std::string | str (bool verbose=false) const

## Data Fields
std::string | name
std::string | type
std::vector< Shape > | shapes
bool | attach

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp